@@ -12,6 +12,7 @@ from __future__ import print_function
 # import udiskie.depend first - for side effects!
 from .depend import has_Notify, has_Gtk, _in_X
 
+import sys
 import inspect
 import logging.config
 import traceback
@@ -24,7 +25,7 @@ import udiskie
 import udiskie.config
 import udiskie.mount
 import udiskie.compat
-from .async_ import AsyncList, Coroutine, Return, RunForever
+from .async_ import AsyncList, Coroutine, Return, Async
 from .common import extend, str2unicode, ObjDictView
 from .locale import _
 
@@ -36,6 +37,15 @@ __all__ = [
 ]
 
 
+def deprecation_warning(text):
+    """Show a deprecation warning."""
+    # NOTE: not using `warnings.warn(text, DeprecationWarning)`, because that
+    # requires starting the python interpreter to be started with `-Wd`, which
+    # in turn shows more warnings about removal of Gtk.StatusIcon.
+    log = logging.getLogger("udiskie.DeprecationWarning")
+    log.warning(_("Deprecation warning: {}", text))
+
+
 @Coroutine.from_generator_function
 def get_backend(version=None):
     """
@@ -46,8 +56,8 @@ def get_backend(version=None):
     :raises GLib.GError: if unable to connect to UDisks dbus service.
     :raises ValueError: if the version is invalid
 
-    If ``version`` has a false truth value, try to connect to UDisks1 and
-    fall back to UDisks2 if not available.
+    If ``version`` has a false truth value, try to connect to UDisks2 and
+    fall back to UDisks1 if not available.
     """
     if not version:
         try:
@@ -60,6 +70,9 @@ def get_backend(version=None):
     elif version == 1:
         import udiskie.udisks1
         daemon = yield udiskie.udisks1.Daemon.create()
+        deprecation_warning(_(
+            'Using UDisks1. Support will be discontinued '
+            'in the next major version of udiskie.'))
     elif version == 2:
         import udiskie.udisks2
         daemon = yield udiskie.udisks2.Daemon.create()
@@ -215,6 +228,11 @@ class _EntryPoint(object):
         self.config = config
         self.options = options
         self.exit_status = 0
+        if sys.version_info < (3,5):
+            deprecation_warning(_(
+                "Running on python {}.{}. The next major version of udiskie "
+                "will require at least python 3.5!",
+                *sys.version_info[:2]))
 
     def program_options(self, args):
         """
@@ -474,7 +492,7 @@ class Daemon(_EntryPoint):
             self.statusicon.activate()
             tasks.append(self.statusicon.instance._icon.task)
         else:
-            tasks.append(RunForever)
+            tasks.append(Async())
         if options['automount']:
             self.automounter.activate()
             tasks.append(self.mounter.add_all())
@@ -598,13 +616,13 @@ class Mount(_EntryPoint):
 
         device_config = config.device_config
         if options['options']:
-            device_config._filters.insert(0, udiskie.config.MountOptions({
+            device_config.insert(0, udiskie.config.MountOptions({
                 'options': [o.strip() for o in options['options'].split(',')],
             }))
 
         prompt = udiskie.prompt.password(options['password_prompt'])
         mounter = udiskie.mount.Mounter(
-            config=config.device_config,
+            config=device_config,
             prompt=prompt,
             udisks=self.udisks)
 
