@@ -18,8 +18,7 @@ import logging
 
 from gi.repository import GLib
 
-from .common import (Emitter, samefile, sameuuid, AttrDictView, decode_ay,
-                     BaseDevice)
+from .common import Emitter, AttrDictView, decode_ay, BaseDevice
 from .dbus import connect_service, MethodsProxy, DBusCallWithFdList, DBusCall
 from .locale import _
 from .async_ import Coroutine, Return
@@ -191,7 +190,9 @@ class Device(BaseDevice):
         This method is used internally to unify the behaviour of top level
         devices in udisks1 and udisks2.
         """
-        return self.drive if self.is_toplevel and not self.is_loop else self
+        # NOTE: always fallback to `self` because udisks2 doesn't report
+        # CryptoBackingDevice nor Drive for logical volumes:
+        return self.is_toplevel and not self.is_loop and self.drive or self
 
     @property
     def is_detachable(self):
@@ -613,6 +614,7 @@ class Daemon(Emitter):
         self.version = version
         self.version_info = tuple(map(int, version.split('.')))
         self.keyfile_support = self.version_info >= (2,6,4)
+        self._log.debug(_('Keyfile support: {0}', self.keyfile_support))
 
         self._proxy = proxy
         self._objects = {}
